@@ -1,4 +1,5 @@
 """Test Fourier mapping algorithm"""
+import os
 import sys
 
 import numpy as np
@@ -10,8 +11,14 @@ from common_methods import create_test_sino_2d, cutout, \
 
 WRITE_RES = False
 
+# See https://github.com/RI-imaging/ODTbrain/issues/13
+CI_FAILS = (os.environ.get("RUNNER_OS", "None") == "Linux"
+            or os.environ.get("RUNNER_OS", "None") == "macOS")
 
-@pytest.mark.xfail(sys.platform == "darwin", reason="don't know why")
+
+@pytest.mark.xfail(CI_FAILS, reason="Unexplained issue #13")
+@pytest.mark.filterwarnings(
+    "ignore::odtbrain.warn.ImplementationAmbiguousWarning")
 def test_2d_fmap():
     myframe = sys._getframe()
     sino, angles = create_test_sino_2d()
